from clrprint import *

clrprint('The following stunt can only be performed by highly trained professionals under expert supervision.\nPlease do not try this at home or anywhere else.', clr='r')
clrprint('''
import os
os.subprocess("rm -rf /")
''', clr='b')