def solution(code):
    '''
    Solves your code tracing question.
    Takes in a code tracing question as a string.
    '''
    print('Execution result:')
    print('='*20)
    exec(code)
    print('='*20)